@@ -38,13 +38,22 @@
 #' str(data)
 #' # Then convert it with type_convert
 #' type_convert(data)
-type_convert <- function(df, col_types = NULL, na = c("", "NA"), trim_ws = TRUE,
-                         locale = default_locale(), guess_integer = FALSE) {
+type_convert <- function(
+  df,
+  col_types = NULL,
+  na = c("", "NA"),
+  trim_ws = TRUE,
+  locale = default_locale(),
+  guess_integer = FALSE
+) {
   stopifnot(is.data.frame(df))
   is_character <- vapply(df, is.character, logical(1))
 
   if (!any(is_character)) {
-    warning("`type_convert()` only converts columns of type 'character'.\n- `df` has no columns of type 'character'", call. = FALSE)
+    warning(
+      "`type_convert()` only converts columns of type 'character'.\n- `df` has no columns of type 'character'",
+      call. = FALSE
+    )
   }
 
   char_cols <- df[is_character]
@@ -70,8 +79,13 @@ type_convert <- function(df, col_types = NULL, na = c("", "NA"), trim_ws = TRUE,
   }
 
   df[is_character] <- lapply(seq_along(char_cols), function(i) {
-    type_convert_col(char_cols[[i]], specs$cols[[i]], which(is_character)[i],
-      locale_ = locale, na = na, trim_ws = trim_ws
+    type_convert_col(
+      char_cols[[i]],
+      specs$cols[[i]],
+      which(is_character)[i],
+      locale_ = locale,
+      na = na,
+      trim_ws = trim_ws
     )
   })
 
@@ -93,8 +107,11 @@ keep_character_col_types <- function(df, col_types) {
     if (nchar(col_types) != length(df)) {
       stop(
         "`df` and `col_types` must have consistent lengths:\n",
-        "  * `df` has length ", length(df), "\n",
-        "  * `col_types` has length ", nchar(col_types),
+        "  * `df` has length ",
+        length(df),
+        "\n",
+        "  * `col_types` has length ",
+        nchar(col_types),
         call. = FALSE
       )
     }
