@@ -44,7 +44,11 @@ test_that("skipping column doesn't pad col_names", {
 test_that("fwf_empty can skip comments", {
   x <- "COMMENT\n1 2 3\n4 5 6"
 
-  out1 <- read_fwf(I(x), fwf_empty(I(x), comment = "COMMENT"), comment = "COMMENT")
+  out1 <- read_fwf(
+    I(x),
+    fwf_empty(I(x), comment = "COMMENT"),
+    comment = "COMMENT"
+  )
   expect_equal(dim(out1), c(2, 3))
 })
 
@@ -103,7 +107,10 @@ test_that("read columns with width, ragged", {
 
 test_that("read_fwf returns an empty data.frame on an empty file", {
   skip_if_edition_second()
-  expect_true(all.equal(read_fwf(test_path("empty-file"), fwf_widths(c(1, 3))), tibble::tibble()))
+  expect_true(all.equal(
+    read_fwf(test_path("empty-file"), fwf_widths(c(1, 3))),
+    tibble::tibble()
+  ))
 })
 
 test_that("check for line breaks in between widths", {
@@ -134,10 +141,26 @@ test_that("check for line breaks in between widths", {
 test_that("ignore commented lines anywhere in file", {
   skip_if_edition_second()
   col_pos <- fwf_positions(c(1, 3, 6), c(2, 5, 6))
-  x1 <- read_fwf(I("COMMENT\n12345A\n67890BBBBBBBBB\n54321C"), col_positions = col_pos, comment = "COMMENT")
-  x2 <- read_fwf(I("12345A\n67890BBBBBBBBB\nCOMMENT\n54321C"), col_positions = col_pos, comment = "COMMENT")
-  x3 <- read_fwf(I("12345A\n67890BBBBBBBBB\n54321C\nCOMMENT"), col_positions = col_pos, comment = "COMMENT")
-  x4 <- read_fwf(I("COMMENT\n12345A\nCOMMENT\n67890BBBBBBBBB\n54321C\nCOMMENT"), col_positions = col_pos, comment = "COMMENT")
+  x1 <- read_fwf(
+    I("COMMENT\n12345A\n67890BBBBBBBBB\n54321C"),
+    col_positions = col_pos,
+    comment = "COMMENT"
+  )
+  x2 <- read_fwf(
+    I("12345A\n67890BBBBBBBBB\nCOMMENT\n54321C"),
+    col_positions = col_pos,
+    comment = "COMMENT"
+  )
+  x3 <- read_fwf(
+    I("12345A\n67890BBBBBBBBB\n54321C\nCOMMENT"),
+    col_positions = col_pos,
+    comment = "COMMENT"
+  )
+  x4 <- read_fwf(
+    I("COMMENT\n12345A\nCOMMENT\n67890BBBBBBBBB\n54321C\nCOMMENT"),
+    col_positions = col_pos,
+    comment = "COMMENT"
+  )
 
   expect_identical(x1, x2)
   expect_identical(x1, x3)
@@ -151,7 +174,10 @@ test_that("error on empty spec (#511, #519)", {
   skip_if_edition_second()
   txt <- "foo\n"
   pos <- fwf_positions(start = numeric(0), end = numeric(0))
-  expect_error(read_fwf(I(txt), pos), "Zero-length.*specifications not supported")
+  expect_error(
+    read_fwf(I(txt), pos),
+    "Zero-length.*specifications not supported"
+  )
 })
 
 test_that("error on negatives in fwf spec", {
@@ -171,7 +197,11 @@ test_that("fwf spec can overlap", {
 # fwf_cols
 test_that("fwf_cols produces correct fwf_positions object with elements of length 2", {
   expected <- fwf_positions(c(1L, 9L, 4L), c(2L, 12L, 6L), c("a", "b", "d"))
-  expect_equal(fwf_cols(a = c(1, 2), b = c(9, 12), d = c(4, 6)), expected, ignore_attr = TRUE)
+  expect_equal(
+    fwf_cols(a = c(1, 2), b = c(9, 12), d = c(4, 6)),
+    expected,
+    ignore_attr = TRUE
+  )
 })
 
 test_that("fwf_cols produces correct fwf_positions object with elements of length 1", {
@@ -208,7 +238,10 @@ test_that("read_table silently reads ragged last column", {
 test_that("read_table skips all comment lines", {
   x <- read_table("foo bar\n1   2\n3   4\n5   6\n")
 
-  y <- read_table("#comment1\n#comment2\nfoo bar\n1   2\n3   4\n5   6\n", comment = "#")
+  y <- read_table(
+    "#comment1\n#comment2\nfoo bar\n1   2\n3   4\n5   6\n",
+    comment = "#"
+  )
 
   expect_equal(x[], y[])
 })
